@@ -5,8 +5,6 @@
 #[allow(non_camel_case_types)]
 #[allow(non_snake_case)]
 #[allow(clippy::all)]
-// FIXME: Remove when https://github.com/rust-lang/rust-bindgen/issues/1651 is closed
-#[allow(deref_nullptr)]
 /// bindgen-generated definitions
 mod bindings {
     include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
@@ -18,12 +16,8 @@ pub use bindings::*;
 // As SPA is a header-only library, global variables and functions are `static` / `static inline`
 // and we need to compile them into a C object ourselves.
 //
-// Also, wrappers around macros are also present here.
+// For functions, this is handled by bindgens "wrap_static_fns" feature.
+//
+// The rest is added in modules here.
 mod type_info;
 pub use type_info::*;
-mod param;
-pub use param::*;
-mod param_audio;
-pub use param_audio::*;
-mod param_video;
-pub use param_video::*;
